%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%% Bi-level FBA
%%% fbamodel: input model
%%% l1_cost: cost vector for level 1 objectives
%%% l2_cost: cost vector for level 2 objectives
%%% verbose (optional): print verbose output
%%% fluxes_L1: computed fluxes in level 1 problem
%%% fluxes_L2: computed fluxes in level 2 problem
%%% obj_L1: value of objective function in level 1 problem
%%% obj_L2: value of objective function in level 2 problem
%%%%%%%%%%%%%%%%%%%%%%%%%%%%
function [fluxes_L1, fluxes_L2, obj_L1, obj_L2] = flux_balance_bilevel(fbamodel, l1_cost, l2_cost, verbose)

if nargin < 4
    verbose = false;
end

param.tmlim  = -1;
param.msglev = 1;
param.save   = 0;

nrxn   = size(fbamodel.rxns,1);
nmetab = size(fbamodel.mets,1);

yt = ones(nrxn,1);

%set up glpk problem for L1
A = [ fbamodel.S; 
      sparse(1:nnz(~yt), find(~yt), ones(nnz(~yt), 1), nnz(~yt), nrxn) ];
b = [ zeros(nmetab, 1);
      zeros(nnz(~yt), 1) ];
ctype = char('S' * ones(1, nmetab + nnz(~yt)));
vartype = char('C' * ones(1, nrxn));

%optimize with L1 objective
[fluxes_L1, obj_L1] = glpk(l1_cost, A, b, fbamodel.lb, fbamodel.ub, ctype, vartype, -1, param);

%set up glpk problem for L2
A = [ fbamodel.S;
      sparse(1:nnz(~yt), find(~yt), ones(nnz(~yt), 1), nnz(~yt), nrxn);
      l1_cost' ];
b = [ zeros(nmetab, 1);
      zeros(nnz(~yt), 1);
      obj_L1 ];
ctype = char('S' * ones(1, nmetab + nnz(~yt) + 1));

%optimize with L2 objective
[fluxes_L2, obj_L2] = glpk(l2_cost, A, b, fbamodel.lb, fbamodel.ub, ctype, vartype, -1, param);

if verbose
    fprintf('Level 1 Objective:    %f\n', obj_L1);
    fprintf('Level 2 Objective:  %f\n', obj_L2);

end