################################################
##                                            ##
##   CONTAMINANT MODEL                        ##
##                                            ##
################################################


#INPUT PARAMETERS
##res_trophic: estimation results of the trophic food web
##LIMmodel_trophic: LIM object for the trophic food web
##res_TL: trophic levels
estimateAndProcessContaminantModel <- function(res_trophic,LIMmodel_trophic,res_TL){
  
  #create LIM input file for the contaminant model based on tabular inputs
  #returns the path of the generated file
  generated_contaminant<-createContaminantInputFile(inputDir="inputs_FW/", 
                                                    outPath="inputs_FW/auto_generated_contaminant.input",
                                                    flowMatrix=res_trophic$flowM,
                                                    biomasses=res_trophic$biomass,
                                                    relativeFlows=FALSE)
  #setup LIM object
  #Create the LIM object from the generated input file
  LIMmodel_contaminant<-Setup(generated_contaminant$genFile)
  
  #######################              
  ##  MCMC ESTIMATION OF 
  ##  BIOACCUMULATION NETWORK
  #######################
  
  #compute flow ranges
  cont_ranges<-Xranges(LIMmodel_contaminant, central=TRUE)
  
  cont_mcmc<-Xsample(LIMmodel_contaminant,jmp=NULL,x0=cont_ranges[,"central"], iter=5000)
  #write MCMC estimation to file
  write.table(cont_mcmc,file="outputs_FW/contaminant/cont_mcmc.txt")
  
  #mean and SD of montecarlo solutions
  mean_sd_cont<-data.frame(Mean = colMeans(cont_mcmc), sd = apply(cont_mcmc, 2, sd))
  write.csv(mean_sd_cont,file="outputs_FW/contaminant/mean_sd.csv")
  #mean of montecarlo solutions (another valid solution)
  mean_cont<-data.frame(Mean = colMeans(cont_mcmc))
  
  
  #######################              
  ##  NETWORK FINAL POST-PROCESSING
  ####################### 
  
  res_contaminant<-estContaminantNet(solution=mean_cont,LIMmodelbiomass=LIMmodel_trophic,
                                     res_biomass=res_trophic,inputParams=generated_contaminant)
  
  #write estimation results to file(s)
  writeContaminantEstimationToFile(res_contaminant,"outputs_FW/contaminant")
  
  ######################################
  ##  ENCODE FW INTO FBA REACTIONS    ##
  ######################################
  writeFlowsAsReactions(res_contaminant,outdir="./",inputParams=generated_contaminant$inputTable)
  
  #return estimated bioaccumulation model
  return(list(LIMmodel_contaminant=LIMmodel_contaminant,res_contaminant=res_contaminant))
}