################################################
##                                            ##
##   TROPHIC MODEL                            ##
##                                            ##
################################################

estimateAndProcessTrophicModel <- function(){
  #create LIM input file for the trophic model based on tabular inputs
  #returns the path of the generated file
  generated_trophic<-createBiomassInputFile(inputDir="inputs_FW/", 
                                            outPath="inputs_FW/auto_generated_trophic.input")
  
  #Create the LIM object from the generated input file
  LIMmodel_trophic<-Setup(generated_trophic$genFile)
  
  #estBiomassNet returns flow matrix, external flows, biomasses and change rates
  #estimate biomass flows (approximate, with "least squares with equality and inequality constraints").
  #overdetermined problem
  #if using Lsei, we need to specifiy which are the exact equalities, examples
  # exacts<-c(generated_trophic$diet_eq_indices)#only diet equations are exact
  # exacts<-c(generated_trophic$diet_eq_indices,
  #           generated_trophic$landDisc_eq_indices)#exact: diet + landings and discards
  exacts<-c(generated_trophic$ingestion_eq_indices,
            generated_trophic$egestion_eq_indices)#exact: ingestion + egestion
  
  res_trophic<-estBiomassNet(LIMmodel_trophic,exactEqs=exacts,method="Lsei",
                             inputParams=generated_trophic$inputTable)
  
  
  #write estimation results to file(s)
  writeBiomassEstimationToFile(res_trophic,"outputs_FW/trophic")
  
  #########################
  ##  TROPHIC LEVELS     ##
  #########################
  
  #trophic level decomposition, excluding external flows. TL of detritus and phytoplankton is 1
  res_TL<-TrophInd(Flow=res_trophic$flowM_no_ext,Dead=c("DETRITUS","PHYTOPLANKTON","DISCARD"))
  write.csv(res_TL,file="outputs_FW/trophic/TL.csv")
  
  #return estimated trophic network and trophic levels
  return(list(LIMmodel_trophic=LIMmodel_trophic,res_trophic=res_trophic,res_TL=res_TL))
}
